%define major 2
%define majorminor 2.1.1
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

# (cg) Should be same version and rel + 1 as module-init-tools.
%define tools_ver 3.16
%define tools_rel 17

%bcond_without dietlibc
%bcond_without tools

Summary: Kernel modules management tools
Name: 	 kmod
Version: 7
Release: %mkrel 6
Source0: http://packages.profusion.mobi/kmod/%{name}-%{version}.tar.xz
%if %{with tools}
Source1: modprobe.default
Source2: modprobe.preload
Source3: blacklist-mga.conf
Source4: ipw-no-associate.conf
# From Fedora module-init-tools package
Source5: blacklist-compat.conf
%endif
# fix more headers:
Patch0:  kmod-7-modprobe-fix-typo-in-config-dump.patch
Patch1:  kmod-3-fix-diet-size_t.diff
Patch2:  kmod-7-modprobe-handle-ENOENT-return-from-init_module.patch

License: GPLv2+
Group: 	 System/Kernel and hardware
#Url1:	 http://www.politreco.com/2011/12/announce-kmod-1/
Url:	 http://git.profusion.mobi/cgit.cgi/kmod.git/
BuildRequires: zlib-devel
BuildRequires: lzma-devel
%if %{with dietlibc}
BuildRequires: dietlibc-devel
%endif
%if %{with tools}
Provides: module-init-tools = %{tools_ver}-%{tools_rel}
Obsoletes: module-init-tools < %{tools_ver}-%{tools_rel}
%endif

%description
Simple tools for managing kernel modules.

%package -n %{libname}
Summary: Kernel modules management library
Group:   System/Libraries
License: LGPLv2+

%description -n %{libname}
Dynamic libraries for %{name}.

The goal of the libkmod library is to offer to other programs the
needed flexibility and fine grained control over insertion, removal,
configuration and listing of kernel modules. Using the library, with
simple pieces of code it's possible to interact with kernel modules
and then there's no need to rely on other tools for that. This is a
thing lacking on Linux for a while and it's one of the items in the
Plumber's Wish List for Linux. Quoting it:

    provide a proper libmodprobe.so from module-init-tools:
    Early boot tools, installers, driver install disks want to access
    information about available modules to optimize boot up handling.

%package -n %{develname}
Summary:	Development files for %{name}
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
License:	LGPLv2+

%description -n %{develname}
Development files and headers for %{name}.



%prep
%setup -q
%apply_patches

%build
%if %{with dietlibc}
mkdir diet
pushd diet
CC="diet gcc" ../configure --with-zlib --with-xz --enable-static --disable-shared --disable-tools
make V=1 LD="diet ld" CC="diet cc" CFLAGS="-Os -D_BSD_SOURCE -D_FILE_OFFSET_BITS=64 -D_GNU_SOURCE -D_ATFILE_SOURCE -DO_CLOEXEC=0 -g -DUINT16_MAX=65535 -DINT32_MAX=2147483647"
popd
%endif

%configure --with-zlib --with-xz
%make

%install
rm -rf %{buildroot}
%makeinstall_std
rm -f %{buildroot}/%_libdir/libkmod.la

# (cg) Move to / until mga3
mkdir -p %{buildroot}/%{_lib}
mv %{buildroot}%{_libdir}/libkmod.so* %{buildroot}/%{_lib}
ln -s /%{_lib}/libkmod.so.%{majorminor} %{buildroot}%{_libdir}/libkmod.so.%{majorminor}
ln -s /%{_lib}/libkmod.so.%{majorminor} %{buildroot}%{_libdir}/libkmod.so.%{major}
ln -s /%{_lib}/libkmod.so.%{majorminor} %{buildroot}%{_libdir}/libkmod.so

mkdir -p %{buildroot}/bin
mv %{buildroot}%{_bindir}/kmod %{buildroot}/bin
ln -s /bin/kmod %{buildroot}%{_bindir}/kmod

%if %{with tools}
  mkdir -p %{buildroot}%{_sbindir} %{buildroot}/sbin
  for tool in modprobe modinfo insmod rmmod depmod lsmod; do
    # (cg) It seems the links in /usr/sbin confuse a dracut initrd build this way
    #      due to various udev rules hardcoding a /sbin/modprobe path...
    #ln -sf ../bin/kmod %{buildroot}%{_sbindir}/$tool
    # (cg) Provide /sbin based binaries for now in case some tools hard code path
    ln -sf ../bin/kmod %{buildroot}/sbin/$tool
  done

  install -d -m755 %{buildroot}%{_sysconfdir}
  install -d -m755 %{buildroot}%{_sysconfdir}/depmod.d
  install -d -m755 %{buildroot}%{_sysconfdir}/modprobe.d/
  touch %{buildroot}%{_sysconfdir}/modprobe.conf
  install -m 644 %{SOURCE1} %{buildroot}%{_sysconfdir}/modprobe.d/00_modprobe.conf
  install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}
  install -m 644 %{SOURCE3} %{SOURCE4} %{SOURCE5} %{buildroot}%{_sysconfdir}/modprobe.d

# (tmb) FIXME for mga3: mga tools still use /etc/modprobe.conf
ln -s  ../modprobe.conf %{buildroot}%{_sysconfdir}/modprobe.d/01_mga-config.conf

%else
  rm -rf %{buildroot}%{_mandir}
%endif

%if %{with dietlibc}
install -m644 ./diet/libkmod/.libs/libkmod.a -D %{buildroot}%{_prefix}/lib/dietlibc/lib-%{_arch}/libkmod.a
%endif

%check
#make test

%clean
rm -rf %{buildroot}

%files
%doc NEWS
/bin/%{name}
%_bindir/%{name}
%if %{with tools}
%dir /etc/depmod.d/
%config(noreplace) %{_sysconfdir}/modprobe.preload
%config(noreplace) %{_sysconfdir}/modprobe.conf
%dir %{_sysconfdir}/modprobe.d/
%config(noreplace) %{_sysconfdir}/modprobe.d/*.conf
#%_sbindir/*
/sbin/*
%_mandir/*/*
%endif

%files -n %{libname}
/%_lib/libkmod.so.%major
/%_lib/libkmod.so.%majorminor
%_libdir/libkmod.so.%major
%_libdir/libkmod.so.%majorminor

%files -n %{develname}
%_libdir/pkgconfig/libkmod.pc
%_includedir/libkmod.h
/%_lib/*.so
%_libdir/*.so
%if %{with dietlibc}
%{_prefix}/lib/dietlibc/lib-%{_arch}/libkmod.a
%endif


%changelog

* Wed May 02 2012 tmb <tmb> 7-6.mga2
+ Revision: 234546
- symlink /etc/modprobe.conf to /etc/modprobe.d/01_mga-config.conf so kmod picks it up

* Sat Apr 28 2012 colin <colin> 7-5.mga2
+ Revision: 234088
- Move libs/binary to / from /usr (sometimes needed to mount /usr under sysvinit)

* Sun Apr 22 2012 tmb <tmb> 7-4.mga2
+ Revision: 232551
- modprobe: handle -ENOENT return from init_module

* Fri Apr 06 2012 tmb <tmb> 7-3.mga2
+ Revision: 229358
- modprobe: fix typo in config dump: option->options (P0, upstream)

* Fri Apr 06 2012 colin <colin> 7-2.mga2
+ Revision: 229352
- Obsolete module-init-tools

* Mon Mar 19 2012 tmb <tmb> 7-1.mga2
+ Revision: 224364
- update to v 7 (bugfix only release)

  + colin <colin>
    - Fix up links for modprobe and friends (only when built --with tools)

* Sat Mar 03 2012 tmb <tmb> 6-1.mga2
+ Revision: 217196
- drop merged patches (P0100-P0102)
- update to v 6

  + colin <colin>
    - Add a build option to build tools to replace module-init-tools (disabled for now)
    - Add configs from module-init-tools
    - Add upstream patches relating to module-init-tools usage

* Sun Feb 26 2012 tv <tv> 5-2.mga2
+ Revision: 215005
- rebuild with new dietlibc

* Tue Feb 07 2012 tmb <tmb> 5-1.mga2
+ Revision: 205901
- bump major
- drop merged P0, P1
- update to v5

  + tv <tv>
    - package NEWS

* Tue Jan 17 2012 tv <tv> 4-1.mga2
+ Revision: 197530
- new release
- better patch 0 for stat time
- drop patch 2 (no more needed with newer dietlibc)

* Sun Jan 15 2012 tv <tv> 3-7.mga2
+ Revision: 196476
- build dietlibc flavor with xz support

* Sat Jan 14 2012 tv <tv> 3-6.mga2
+ Revision: 196177
- disable debugging in dietlibc build

* Fri Jan 13 2012 tv <tv> 3-5.mga2
+ Revision: 195808
- fix libname
- fix libname

* Fri Jan 13 2012 tv <tv> 3-3.mga2
+ Revision: 195786
- build (& fix build) with dietlibc
- run make test
- disable static library

* Fri Jan 06 2012 tv <tv> 3-2.mga2
+ Revision: 192240
- install kmod-* tools in order to test
- eanble xz compressed modules support
- reeanble zlib support again
- build static library for insaller stage1

* Thu Jan 05 2012 tmb <tmb> 3-1.mga2
+ Revision: 191693
- update to v 3

* Tue Jan 03 2012 tv <tv> 2-2.mga2
+ Revision: 190165
- enable zlib

* Sat Dec 24 2011 tmb <tmb> 2-1.mga2
+ Revision: 187113
- fix libkmod.pc path
- update to version 2
- drop buildroot and defattr

  + tv <tv>
    - fix library license tag
    - imported package kmod

